function dx = EDOS_Unespv2(t,x,glu,Konsrna)

%% Chemical species modeled
% CCpat = x(1);
% mRNAtet = x(2);
% TetR = x(3);
% sRNA = x(4);
% mRNAT7 = x(5);
% T7pol = x(6);
% mRNAins = x(7);
% mRNAins-sRNA = x(8) ;
% Ins = x(9);

dx = zeros(size(x));

%% Parameters

CcpATot = 350; %nM
pveg1 = 0.85 ; %nMs-1 
pveg0 = 0.0425; %nMs-1
ptet = 0.85 ;%nMs-1           %transcription rate
ptet0 = 0.0425; %nMs-1    %Leakage
pT7 = 1.7;%nMs-1 double transcription rate
nc = 2;                     % Hill coefficient
nt = 3;                     % Hill coefficient for TetR
KGlu = 1300; %nM            %CAP similar
Kccpa = 0.028; %nM
atetr =  2.3e-2 ; %1/s                %Degradation proteins
aT7 = 5.81e-2
ains = 2.3e-3
drna = 4.1e-3; %1/s % 8e-4 min-1   %Degradation mRNA
drna2 = 4.1e-4;
drna3 = 4.1e-3;
trsl = 0.05; %0.027;  % s-1    %Translation Rate
trsl2 = 0.0172;  % s-1    %Translation Rate
trsl3 = 0.2631;  % s-1    %Translation Rate
Ktet = 5.6 ; %nM
KT7 = 3;  %nM             % Affinity constant

%% Mass Conservation

CcpA0 = CcpATot - x(1) ;

%% ODEs

dx(1) =  CcpA0*(glu/((KGlu)+(glu))) ;
dx(2) =  pveg1*(1/((x(1)/Kccpa)^nc + 1)) + pveg0 - drna*x(2); % mRNATetR expression under activated CCpa(*CCpa)
dx(3) =  trsl*x(2) - atetr*x(3); %TetR over time
dx(4) =  pveg1*(1/((x(1)/Kccpa)^nc + 1)) + pveg0 - drna2*x(4); % sRNA expression under activated CCpa(*CCpa)
dx(5) =  ptet*(1/((x(3)/Ktet)^nt + 1)) + ptet0 - drna*x(5); %T7 gene expression under TetR regulation
dx(6) =  trsl2*x(5) - aT7*x(6); %T7 pol. over time
dx(7) =  pT7*(x(6))^nc/((x(6))^nc + KT7) - Konsrna*x(4)*x(7) - drna*x(7); %Insulin gene expression under T7 transcription system
dx(8) =  Konsrna*x(7)*x(4)-drna3*x(8);
dx(9) =  pveg0 + trsl3*x(7)-ains*x(9); %Insulin over time

end